@@ -339,7 +339,7 @@ class Crp:
 
 
     def buildDF(self,original_dataset:pd.DataFrame,lag:int,train_window:int,customer_name:str,
-                                sq_pass:str,items_dataset:pd.DataFrame = None,lastTimeflagParam):
+                                sq_pass:str,items_dataset,lastTimeflagParam):
         """
         Params:
             original_dataset - > the original raw data 
